pub struct PacingLimits {
pub total_concurrency: usize,
pub refusal_threshold: u32,
pub recovery_threshold: u32,
pub jitter: Duration,
pub max_backoff: Duration,
pub is_cautious: bool,
pub per_registry: Option<usize>,
pub rate: Option<u32>,
}Fields
total_concurrency: usizerefusal_threshold: u32recovery_threshold: u32jitter: Duration@docgen A spread is added before each request so a fan-out does not land on a registry as one spike.
max_backoff: Durationis_cautious: boolper_registry: Option<usize>rate: Option<u32>Implementations