pub struct Extension {
pub suffix: Suffix,
pub kind: ExtensionKind,
pub rank: Option<u32>,
pub industries: Vec<String>,
pub region: Option<String>,
pub country: Option<String>,
pub registrable: bool,
pub repurposed: bool,
}Fields
suffix: Suffixkind: ExtensionKindrank: Option<u32>@docgen None means the zone is too small or too private to rank, so absence is not missing data.
industries: Vec<String>region: Option<String>country: Option<String>registrable: boolrepurposed: boolImplementations